var Direction;

(function (Direction) {
  Direction["X"] = "x";
  Direction["Y"] = "y";
})(Direction || (Direction = {})); // get the relative distance from destination


var getRelativeDistance = function getRelativeDistance(target, parent, attrMap) {
  if (typeof target === 'number') return target;

  if (typeof target === 'string') {
    var elm = document.querySelector(target);

    if (!elm) {
      console.warn('Please pass correct selector string for scrollTo()!');
      return 0;
    }

    var dis = elm.getBoundingClientRect()[attrMap.leftTop] - parent.getBoundingClientRect()[attrMap.leftTop];
    return dis;
  }

  return 0;
};

var useSmoothScroll = function useSmoothScroll(_ref) {
  var ref = _ref.ref,
      speed = _ref.speed,
      _ref$direction = _ref.direction,
      direction = _ref$direction === void 0 ? Direction.Y : _ref$direction,
      _ref$threshold = _ref.threshold,
      threshold = _ref$threshold === void 0 ? 1 : _ref$threshold;
  var attrMap = {
    leftTop: Direction.X === direction ? 'left' : 'top',
    offsetLeftTop: Direction.X === direction ? 'offsetLeft' : 'offsetTop',
    offsetWidthHeight: Direction.X === direction ? 'offsetWidth' : 'offsetHeight',
    scrollLeftTop: Direction.X === direction ? 'scrollLeft' : 'scrollTop',
    scrollWidthHeight: Direction.X === direction ? 'scrollWidth' : 'scrollHeight',
    clientWidthHeight: Direction.X === direction ? 'clientWidth' : 'clientHeight'
  };

  var scrollTo = function scrollTo(target) {
    if (!ref || !ref.current) {
      console.warn('Please pass `ref` property for your scroll container! \n Get more info at https://github.com/ron0115/react-smooth-scroll-hook');
      return;
    }

    var elm = ref.current;
    if (!elm) return;

    if (!target) {
      console.warn('Please pass a valid property for `scrollTo()`! \n Get more info at https://github.com/ron0115/react-smooth-scroll-hook');
    }

    var initScrollLeftTop = elm[attrMap.scrollLeftTop];
    var distance = getRelativeDistance(target, elm, attrMap);
    if (distance === 0) return;

    if (elm.scrollTo && !speed) {
      var _elm$scrollTo;

      elm.scrollTo((_elm$scrollTo = {}, _elm$scrollTo[attrMap.leftTop] = elm[attrMap.scrollLeftTop] + distance, _elm$scrollTo.behavior = 'smooth', _elm$scrollTo));
    } else {
      var _speed = speed || 100;

      var cb = function cb() {
        // scroll to edge
        if (distance > 0 ? elm[attrMap.scrollLeftTop] + elm[attrMap.clientWidthHeight] >= elm[attrMap.scrollWidthHeight] : elm[attrMap.scrollLeftTop] === 0) {
          return;
        }

        var gone = function gone() {
          return Math.abs(elm[attrMap.scrollLeftTop] - initScrollLeftTop);
        };

        if (Math.abs(distance) - gone() < _speed) {
          _speed = Math.abs(distance) - gone();
        } // distance to run every frame，always 1/60s


        elm[attrMap.scrollLeftTop] += _speed * (distance > 0 ? 1 : -1); // reach destination, threshold defaults to 1

        if (Math.abs(gone() - Math.abs(distance)) < threshold) {
          return;
        }

        requestAnimationFrame(cb);
      };

      requestAnimationFrame(cb);
    }
  };

  return {
    scrollTo: scrollTo
  };
};

export default useSmoothScroll;
export { Direction, useSmoothScroll };
//# sourceMappingURL=react-smooth-scroll-hook.esm.js.map
